// ========================================
// Fire extinguisher
// -----------------------------------------
// Made for Persistence of vision 3.6
//==========================================  
// Copyright 2006 Gilles Tran http://www.oyonale.com
// -----------------------------------------
// This work is licensed under the Creative Commons Attribution License. 
// To view a copy of this license, visit http://creativecommons.org/licenses/by/2.0/ 
// or send a letter to Creative Commons, 559 Nathan Abbott Way, Stanford, California 94305, USA.
// You are free:
// - to copy, distribute, display, and perform the work
// - to make derivative works
// - to make commercial use of the work
// Under the following conditions:
// - Attribution. You must give the original author credit.
// - For any reuse or distribution, you must make clear to others the license terms of this work.
// - Any of these conditions can be waived if you get permission from the copyright holder.
// Your fair use and other rights are in no way affected by the above. 
//========================================== 
//+w480 +h640 +F +A 
#include "colors.inc"
#declare RadOK=2; // 0=no radiosity ; 1= low quality rad; 2= good quality
#declare ExtinguisherOK=1; // turns all snails on
#declare AreaOK=1; // area light
global_settings {
    max_trace_level 5
    //---------------------------------------
    // change gamma if necessary (scene too bright for instance)
    //---------------------------------------
    assumed_gamma 1
    //---------------------------------------
    noise_generator 1
    #if (RadOK>0)
        radiosity{
            #switch (RadOK)
                #case (1)
                    count 35 error_bound 1.8 
                #break
                #case (2)
                    count 100 error_bound 0.1 
                #break
            #end    
            nearest_count 5 
            recursion_limit 1  
            low_error_factor 0.2 
            gray_threshold 0 
            minimum_reuse 0.015 
            brightness 1 
            adc_bailout 0.01/2      
            normal on
            media off
        }
    #end
}


#declare Camera=camera{
        location z*-200+y*50
        direction z*1.6
        up y
        right x*image_width/image_height
        look_at <0,49,0>
}
#declare Camera2=camera{ // test camera
      location z*-1000+y*1000
      direction z*1
      up y
      right x*image_width/image_height
      look_at <0,2,0>
}
camera{Camera translate x*15}
//camera{Camera2}

#declare C_Sun= rgb <1,0.9,0.8>;

light_source{-z*10000,color C_Sun*2 rotate x*30 rotate y*80
    #if (AreaOK=1)
        area_light 50*x,50*y,5,5 adaptive 1 jitter orient circular
    #end
}


//sky_sphere{pigment{gradient y color_map{[0.5 White*7][0.7 rgb <92,126,202>*7/225]}}}
sky_sphere{pigment{gradient y color_map{[0.3 White][0.6 rgb <92,126,202>/225]}}}



#if (ExtinguisherOK=1)
    
#declare T_Bottle= texture{
    pigment {uv_mapping image_map{png "extinguisher_map.png" interpolate 2} scale <-1,1,1>}
    finish{ambient 0 diffuse 0.6 specular 1 roughness 1/20 reflection {0.1,0.8 fresnel on}}
}    
#declare T_Alu=texture{
    pigment {color rgb 0.6} 
    finish{ambient 0 diffuse 1 metallic brilliance 6 specular 0.3 roughness 0.1 reflection {0,1 fresnel on metallic}}
}    
#declare T_Pin= texture{
    pigment {color rgb <0,0.5,0.8>} 
    finish{ambient 0 diffuse 1 specular 0.4 roughness 0.05}
}    
#declare T_Handle= texture{
    pigment {color rgb <0,0,0>} 
    finish{ambient 0 diffuse 1 specular 1 roughness 0.03 reflection {0,1 fresnel on}}
}    
#declare T_Brass=texture{
    pigment {color rgb <0.5,0.25,0.03>} 
    finish{ambient 0 diffuse 0.5 metallic brilliance 8 specular 1 roughness 0.05 reflection {0.1,1 fresnel on metallic}}
}    
#declare T_Pipe= texture{
    pigment {color rgb <0,0,0>}  
    normal{bumps 0.3 scale 1}
    finish{ambient 0 diffuse 1 specular 0.5 roughness 0.1 reflection {0,0.1 fresnel on}}
} 
    
    
    #include "extinguisher.inc"
    #declare Extinguisher=object{
        Extinguisher
        interior{ior 1.5}
    } 
#else
    #declare Extinguisher=cylinder{0,y*40,10 texture{pigment{Red}finish{ambient 0 diffuse 1 specular 0.05 roughness 0.01}}}
#end
// stone ground
#declare Ground=plane{y,0 
    texture{
        pigment{
            bozo turbulence 1 lambda 3 color_map{[0 rgb <0.9,0.93,0.91>*0.7][1 rgb <0.64,0.62,0.59>*0.5]}
            scale 50
        }

        normal{
            bump_map{jpeg "stone09.jpg"} 
            bump_size -5
            rotate x*90
            scale 200
        }

        finish{
            ambient 0 
            diffuse 1
        }
       
        rotate -y*20
    }
}
//==========================================  
// All the objets
//==========================================  

object{Ground}
object{Ground rotate x*-90 translate z*11}
object{Extinguisher rotate y*120}
